@@ -37,7 +37,7 @@
        Keith Owens <kaos@ocs.com.au> April 2000.
    */
 
-#ident "$Id: depmod.c 1.22 Sun, 10 Sep 2000 11:25:29 +1100 kaos $"
+#ident "$Id: depmod.c 1.23 Sat, 23 Sep 2000 14:13:54 +1100 kaos $"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -545,7 +545,7 @@ static int addksyms(char *file_syms)
 		/* The second word is either the symbol name or a type */
 		if (p && strlen(p) == 1) { /* System.map */
 			is_mapfile = 1;
-			if (!isupper(*p))
+			if (*p != '?')
 				p = NULL;
 			else
 				p = strtok(NULL, " \t\n");
@@ -563,9 +563,12 @@ static int addksyms(char *file_syms)
 			strtok(line, " \t\n"); /* Skip first word */
 			p = strtok(NULL, " \n");
 			if (is_mapfile) {
-				if (!isupper(*p))
+				if (*p != '?')
 					continue;
 				p = strtok(NULL, " \t\n");
+				if (strncmp(p, "__kstrtab_", 10))
+					continue;
+				p += 10;
 			}
 			assert(n_syms < MAX_MAP_SYM);
 			symtab[n_syms++] = addsym(p, mod, SYM_DEFINED, 0);
