@@ -23,7 +23,7 @@
 #ifndef MODUTILS_MODULE_H
 #define MODUTILS_MODULE_H 1
 
-#ident "$Id: module.h 1.3 Mon, 17 Apr 2000 20:38:59 -0700 kaos $"
+#ident "$Id: module.h 1.5 Wed, 30 Aug 2000 13:52:44 +1100 kaos $"
 
 /* This file contains the structures used by the 2.0 and 2.1 kernels.
    We do not use the kernel headers directly because we do not wish
@@ -158,6 +158,9 @@ struct module
   unsigned tgt_long runsize;
   unsigned tgt_long kallsyms_start;
   unsigned tgt_long kallsyms_end;
+  unsigned tgt_long archdata_start;
+  unsigned tgt_long archdata_end;
+  unsigned tgt_long kernel_data;
 };
 
 struct module_info
