@@ -24,7 +24,7 @@
 #ifndef MODUTILS_OBJ_H
 #define MODUTILS_OBJ_H 1
 
-#ident "$Id: obj.h 1.9 Mon, 07 Aug 2000 01:07:12 -0700 kaos $"
+#ident "$Id: obj.h 1.11 Fri, 08 Sep 2000 16:46:27 +1100 kaos $"
 
 /* The relocatable object is manipulated using elfin types.  */
 
@@ -82,7 +82,7 @@ struct obj_symbol
   int secidx;			/* the defining section index/module */
   int info;
   int ksymidx;			/* for export to the kernel symtab */
-  int referenced;		/* actually used in the link */
+  int r_type;			/* relocation type */
 };
 
 /* Hardcode the hash table size.  We shouldn't be needing so many
@@ -166,6 +166,7 @@ struct obj_symbol_patch_struct
 #define arch_init_module		ObjW(arch_init_module)
 #define arch_load_proc_section		ObjW(arch_load_proc_section)
 #define arch_finalize_section_address	ObjW(arch_finalize_section_address)
+#define arch_archdata			ObjW(arch_archdata)
 
 unsigned long obj_elf_hash (const char *);
 
@@ -250,4 +251,8 @@ int arch_load_proc_section (struct obj_section *sec, int fp);
 
 int arch_finalize_section_address (struct obj_file *f, ElfW(Addr) base);
 
+int arch_archdata (struct obj_file *fin, struct obj_section *sec);
+
+#define ARCHDATA_SEC_NAME "__archdata"
+
 #endif /* obj.h */
