@@ -46,9 +46,11 @@
        Keith Owens <kaos@ocs.com.au> December 1999.
      kallsyms support
        Keith Owens <kaos@ocs.com.au> April 2000.
+     archdata support
+       Keith Owens <kaos@ocs.com.au> August 2000.
    */
 
-#ident "$Id: insmod.c 1.25 Sun, 13 Aug 2000 06:45:56 -0700 kaos $"
+#ident "$Id: insmod.c 1.27 Sun, 10 Sep 2000 11:25:29 +1100 kaos $"
 
 #include <sys/types.h>
 #include <stdlib.h>
@@ -993,6 +995,31 @@ static int add_kallsyms(struct obj_file *f,
 	return 0;
 }
 
+
+/* Add an arch data section if the arch wants it. */
+static int add_archdata(struct obj_file *f,
+			struct obj_section **sec)
+{
+	size_t i;
+
+	*sec = NULL;
+	/* Add an empty archdata section to the module if necessary */
+	for (i = 0; i < f->header.e_shnum; ++i) {
+		if (strcmp(f->sections[i]->name, ARCHDATA_SEC_NAME) == 0) {
+			*sec = f->sections[i];
+			break;
+		}
+	    }
+	if (!*sec)
+		*sec = obj_create_alloced_section(f, ARCHDATA_SEC_NAME, 16, 0);
+
+	/* Size and populate archdata */
+	if (arch_archdata(f, *sec))
+		return(1);
+	return 0;
+}
+
+
 static int init_module(const char *m_name, struct obj_file *f,
 		       unsigned long m_size)
 {
@@ -1039,6 +1066,11 @@ static int init_module(const char *m_name, struct obj_file *f,
 		    module->runsize > sec->header.sh_addr - m_addr)
 			module->runsize = sec->header.sh_addr - m_addr;
 	}
+	sec = obj_find_section(f, ARCHDATA_SEC_NAME);
+	if (sec && sec->header.sh_size) {
+		module->archdata_start = sec->header.sh_addr;
+		module->archdata_end = module->archdata_start + sec->header.sh_size;
+	}
 	sec = obj_find_section(f, KALLSYMS_SEC_NAME);
 	if (sec && sec->header.sh_size) {
 		module->kallsyms_start = sec->header.sh_addr;
@@ -1252,7 +1284,7 @@ int INSMOD_MAIN(int argc, char **argv)
 	char *filename;
 	int fp;
 	struct obj_file *f;
-	struct obj_section *kallsyms = NULL;
+	struct obj_section *kallsyms = NULL, *archdata = NULL;
 	int o;
 	int noload = 0;
 	int dolock = 1; /*Note: was: 0; */
@@ -1331,7 +1363,7 @@ int INSMOD_MAIN(int argc, char **argv)
 	}
 	filename = argv[optind++];
 
-	if (config_read(0, NULL, NULL, NULL) < 0) {
+	if (config_read(0, NULL, "", NULL) < 0) {
 		error("Failed handle configuration");
 	}
 
@@ -1466,6 +1498,10 @@ int INSMOD_MAIN(int argc, char **argv)
 	if (k_new_syscalls)
 		create_module_ksymtab(f);
 
+	/* archdata based on relocatable addresses */
+	if (add_archdata(f, &archdata))
+		goto out;
+
 	/* kallsyms based on relocatable addresses */
 	if (add_kallsyms(f, &kallsyms))
 		goto out;
@@ -1519,6 +1555,10 @@ int INSMOD_MAIN(int argc, char **argv)
 		goto out;
 	}
 
+	/* Do archdata again, this time we have the final addresses */
+	if (add_archdata(f, &archdata))
+		goto out;
+
 	/* Do kallsyms again, this time we have the final addresses */
 	if (add_kallsyms(f, &kallsyms))
 		goto out;
