@@ -21,7 +21,7 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-#ident "$Id: obj_load.c 1.6 Sat, 08 Jul 2000 21:19:11 -0700 kaos $"
+#ident "$Id: obj_load.c 1.7 Fri, 08 Sep 2000 16:46:27 +1100 kaos $"
 
 #include <alloca.h>
 #include <string.h>
@@ -230,15 +230,64 @@ obj_load (int fp, Elf32_Half e_type, const char *filename)
 	      }
 	  }
 	break;
+	}
+    }
 
+  /* second pass to add relocation data to symbols */
+  for (i = 0; i < shnum; ++i)
+    {
+      struct obj_section *sec = f->sections[i];
+      switch (sec->header.sh_type)
+	{
 	case SHT_RELM:
-	  if (sec->header.sh_entsize != sizeof(ElfW(RelM)))
-	    {
-	      error("relocation entry size mismatch: %lu != %lu",
-		    (unsigned long)sec->header.sh_entsize,
-		    (unsigned long)sizeof(ElfW(RelM)));
-	      return NULL;
-	    }
+	  {
+	    unsigned long nrel, j;
+	    ElfW(RelM) *rel;
+	    struct obj_section *symtab;
+	    char *strtab;
+	    if (sec->header.sh_entsize != sizeof(ElfW(RelM)))
+	      {
+		error("relocation entry size mismatch: %lu != %lu",
+		      (unsigned long)sec->header.sh_entsize,
+		      (unsigned long)sizeof(ElfW(RelM)));
+		return NULL;
+	      }
+
+	    nrel = sec->header.sh_size / sizeof(ElfW(RelM));
+	    rel = (ElfW(RelM) *) sec->contents;
+	    symtab = f->sections[sec->header.sh_link];
+	    strtab = f->sections[symtab->header.sh_link]->contents;
+
+	    /* Save the relocate type in each symbol entry.  */
+	    for (j = 1, ++rel; j < nrel; ++j, ++rel)
+	      {
+		ElfW(Sym) *extsym;
+		struct obj_symbol *intsym;
+		unsigned long symndx;
+		symndx = ELFW(R_SYM)(rel->r_info);
+		if (symndx)
+		  {
+		    extsym = ((ElfW(Sym) *) symtab->contents) + symndx;
+		    if (ELFW(ST_BIND)(extsym->st_info) == STB_LOCAL)
+		      {
+			/* Local symbols we look up in the local table to be sure
+			   we get the one that is really intended.  */
+			intsym = f->local_symtab[symndx];
+		      }
+		    else
+		      {
+			/* Others we look up in the hash table.  */
+			const char *name;
+			if (extsym->st_name)
+			  name = strtab + extsym->st_name;
+			else
+			  name = f->sections[extsym->st_shndx]->name;
+			intsym = obj_find_symbol(f, name);
+		      }
+		    intsym->r_type = ELFW(R_TYPE)(rel->r_info);
+		  }
+	      }
+	  }
 	  break;
 	}
     }
