@@ -205,7 +205,7 @@ char *below[] =
 /*
  * This is the list of pre-defined "prune"s,
  * used to exclude paths from scan of /lib/modules.
- * Each entry can be overridden by an entry in /etc/modules.conf
+ * /etc/modules.conf can add entries but not remove them.
  */
 char *prune[] =
 {
@@ -214,5 +214,9 @@ char *prune[] =
 	"System.map",
 	".config",
 	"build",		/* symlink to source tree */
+	"vmlinux",
+	"vmlinuz",
+	"bzImage",
+	"zImage",
 	NULL			/* marks the end of the list! */
 };
