@@ -1566,7 +1566,7 @@ char *search_module_path(const char *base)
 {
 	GLOB_LIST *g;
 
-	if (config_read(0, NULL, NULL, NULL) < 0)
+	if (config_read(0, NULL, "", NULL) < 0)
 		return NULL;
 	/* else */
 	g = config_lstmod(base, NULL, 1);
