@@ -160,7 +160,8 @@ int meta_expand(char *pt, GLOB_LIST *g, char *base_dir, char *version)
 	int len = 0;
 	char *line = NULL;
 	char *p;
-	char tmpline[PATH_MAX + 11];
+	char tmpline[PATH_MAX + 1];
+	char tmpcmd[PATH_MAX + 11];
 
 	g->pathc = 0;
 	g->pathv = NULL;
@@ -281,9 +282,10 @@ int meta_expand(char *pt, GLOB_LIST *g, char *base_dir, char *version)
 	/*
 	 * Last resort: Use "echo"
 	 */
-	sprintf(tmpline, "/bin/echo %s%s", (base_dir ? base_dir : ""), pt);
-	if ((fin = popen(tmpline, "r")) == NULL) {
-		error("Can't execute: %s", tmpline);
+	sprintf(tmpline, "%s%s", (base_dir ? base_dir : ""), pt);
+	sprintf(tmpcmd, "/bin/echo %s", tmpline);
+	if ((fin = popen(tmpcmd, "r")) == NULL) {
+		error("Can't execute: %s", tmpcmd);
 		return -1;
 	}
 	/* else */
@@ -291,18 +293,21 @@ int meta_expand(char *pt, GLOB_LIST *g, char *base_dir, char *version)
 	/*
 	 * Collect the result
 	 */
-	while (fgets(tmpline, PATH_MAX, fin) != NULL) {
-		int l = strlen(tmpline);
+	while (fgets(tmpcmd, PATH_MAX, fin) != NULL) {
+		int l = strlen(tmpcmd);
 
 		line = (char *)xrealloc(line, len + l + 1);
 		line[len] = '\0';
-		strcat(line + len, tmpline);
+		strcat(line + len, tmpcmd);
 		len += l;
 	}
 	pclose(fin);
 
 	if (line) {
-		split_line(g, line, 0);
+		/* Ignore result if no expansion occurred */
+		strcat(tmpline, "\n");
+		if (strcmp(tmpline, line))
+			split_line(g, line, 0);
 		free(line);
 	}
 
